==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QTexture2DMultisample.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DMultisample target format</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisample.html">Qt3DRender::QTexture2DMultisample</a></p>
 */
public class QTexture2DMultisample extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisample.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisample(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisample() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisample.html#QTexture2DMultisample">Qt3DRender::QTexture2DMultisample::QTexture2DMultisample(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisample(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisample instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisample(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisample(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DMultisample instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QTexture2DMultisample.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DMultisample target format</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisample.html">Qt3DRender::QTexture2DMultisample</a></p>
 */
public class QTexture2DMultisample extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DMultisample.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DMultisample(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DMultisample() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2dmultisample.html#QTexture2DMultisample">Qt3DRender::QTexture2DMultisample::QTexture2DMultisample(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DMultisample(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DMultisample instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisample(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DMultisample(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DMultisample instance, QDeclarativeConstructor constructor);
    
}
